==> more_leaf_particles-1.2.2%2B1.21.8-sources.jar: net/fellter/moreLeafParticles/mixin/TintedParticleLeavesBlockMixin.java <==
package net.fellter.moreLeafParticles.mixin;

import com.llamalad7.mixinextras.injector.wrapoperation.Operation;
import com.llamalad7.mixinextras.injector.wrapoperation.WrapOperation;
import net.fellter.moreLeafParticles.ModParticles;
import net.fellter.moreLeafParticles.MoreLeafParticles;
import net.fellter.moreLeafParticles.yacl.ModConfig;
import net.minecraft.class_10716;
import net.minecraft.class_1937;
import net.minecraft.class_2246;
import net.minecraft.class_2338;
import net.minecraft.class_2394;
import net.minecraft.class_2397;
import net.minecraft.class_2398;
import net.minecraft.class_5819;
import net.minecraft.class_9381;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;

@Mixin(class_10716.class)
abstract class TintedParticleLeavesBlockMixin extends class_2397 {
	private TintedParticleLeavesBlockMixin(float leafParticleChance, class_2251 settings) {
		super(leafParticleChance, settings);
	}

	@WrapOperation(method = "spawnLeafParticle", at = @At(value = "INVOKE", target = "Lnet/minecraft/particle/ParticleUtil;spawnParticle(Lnet/minecraft/world/World;Lnet/minecraft/util/math/BlockPos;Lnet/minecraft/util/math/random/Random;Lnet/minecraft/particle/ParticleEffect;)V"))
	private void fellter$spawnLeafParticle(class_1937 world, class_2338 pos, class_5819 random, class_2394 effect, Operation<Void> original) {
		if (MoreLeafParticles.isYACLPresent()) {
			if (this == class_2246.field_9988) {
				effect = ModConfig.enableSpruce ? class_9381.method_58256(ModParticles.SPRUCE_NEEDLES, world.method_67233(pos)) : null;
			} else if (this == class_2246.field_10539) {
				effect = ModConfig.enableBirch ? class_9381.method_58256(ModParticles.BIRCH_LEAVES, world.method_67233(pos)) : null;
			} else if (this == class_2246.field_37551) {
				effect = ModConfig.enableMangrove ? class_9381.method_58256(ModParticles.MANGROVE_LEAVES, world.method_67233(pos)) : null;
			} else if (this == class_2246.field_10335) {
				effect = ModConfig.enableJungle ? class_9381.method_58256(ModParticles.JUNGLE_LEAVES, world.method_67233(pos)) : null;
			} else if (this == class_2246.field_10098) {
				effect = ModConfig.enableAcacia ? class_9381.method_58256(ModParticles.ACACIA_LEAVES, world.method_67233(pos)) : null;
			} else if (this == class_2246.field_10035) {
				effect = ModConfig.enableDarkOak ? class_9381.method_58256(ModParticles.DARK_OAK_LEAVES, world.method_67233(pos)) : null;
			} else if (this == class_2246.field_10503) {
				effect = ModConfig.enableOak ? class_9381.method_58256(class_2398.field_55880, world.method_67233(pos)) : null;
			}

			if (effect != null) {
				original.call(world, pos, random, effect);
			}
		} else {
			if (this == class_2246.field_9988) {
				effect = class_9381.method_58256(ModParticles.SPRUCE_NEEDLES, world.method_67233(pos));
			} else if (this == class_2246.field_10539) {
				effect = class_9381.method_58256(ModParticles.BIRCH_LEAVES, world.method_67233(pos));
			} else if (this == class_2246.field_37551) {
				effect = class_9381.method_58256(ModParticles.MANGROVE_LEAVES, world.method_67233(pos));
			} else if (this == class_2246.field_10335) {
				effect = class_9381.method_58256(ModParticles.JUNGLE_LEAVES, world.method_67233(pos));
			} else if (this == class_2246.field_10098) {
				effect = class_9381.method_58256(ModParticles.ACACIA_LEAVES, world.method_67233(pos));
			} else if (this == class_2246.field_10035) {
				effect = class_9381.method_58256(ModParticles.DARK_OAK_LEAVES, world.method_67233(pos));
			}

			original.call(world, pos, random, effect);
		}
	}
}

==> more_leaf_particles-1.3.1%2B1.21.10-sources.jar: net/fellter/moreLeafParticles/mixin/TintedParticleLeavesBlockMixin.java <==
package net.fellter.moreLeafParticles.mixin;

import com.llamalad7.mixinextras.injector.wrapoperation.Operation;
import com.llamalad7.mixinextras.injector.wrapoperation.WrapOperation;
import net.fellter.moreLeafParticles.ModParticles;
import net.fellter.moreLeafParticles.MoreLeafParticles;
import net.fellter.moreLeafParticles.yacl.ModConfig;
import net.minecraft.class_10716;
import net.minecraft.class_1937;
import net.minecraft.class_2246;
import net.minecraft.class_2338;
import net.minecraft.class_2394;
import net.minecraft.class_2397;
import net.minecraft.class_2398;
import net.minecraft.class_5819;
import net.minecraft.class_9381;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;

@Mixin(class_10716.class)
public abstract class TintedParticleLeavesBlockMixin extends class_2397 {
	public TintedParticleLeavesBlockMixin(float leafParticleChance, class_2251 settings) {
		super(leafParticleChance, settings);
	}

	@WrapOperation(method = "spawnLeafParticle", at = @At(value = "INVOKE", target = "Lnet/minecraft/particle/ParticleUtil;spawnParticle(Lnet/minecraft/world/World;Lnet/minecraft/util/math/BlockPos;Lnet/minecraft/util/math/random/Random;Lnet/minecraft/particle/ParticleEffect;)V"))
	private void fellter$spawnLeafParticle(class_1937 world, class_2338 pos, class_5819 random, class_2394 effect, Operation<Void> original) {
		if (MoreLeafParticles.isYACLPresent()) {
			if (this == class_2246.field_9988) {
				effect = ModConfig.enableSpruce ? class_9381.method_58256(ModParticles.SPRUCE_NEEDLES, world.method_67233(pos)) : null;
			} else if (this == class_2246.field_10539) {
				effect = ModConfig.enableBirch ? class_9381.method_58256(ModParticles.BIRCH_LEAVES, world.method_67233(pos)) : null;
			} else if (this == class_2246.field_37551) {
				effect = ModConfig.enableMangrove ? class_9381.method_58256(ModParticles.MANGROVE_LEAVES, world.method_67233(pos)) : null;
			} else if (this == class_2246.field_10335) {
				effect = ModConfig.enableJungle ? class_9381.method_58256(ModParticles.JUNGLE_LEAVES, world.method_67233(pos)) : null;
			} else if (this == class_2246.field_10098) {
				effect = ModConfig.enableAcacia ? class_9381.method_58256(ModParticles.ACACIA_LEAVES, world.method_67233(pos)) : null;
			} else if (this == class_2246.field_10035) {
				effect = ModConfig.enableDarkOak ? class_9381.method_58256(ModParticles.DARK_OAK_LEAVES, world.method_67233(pos)) : null;
			} else if (this == class_2246.field_10503) {
				effect = ModConfig.enableOak ? class_9381.method_58256(class_2398.field_55880, world.method_67233(pos)) : null;
			}

			if (effect != null) {
				original.call(world, pos, random, effect);
			}
		} else {
			if (this == class_2246.field_9988) {
				effect = class_9381.method_58256(ModParticles.SPRUCE_NEEDLES, world.method_67233(pos));
			} else if (this == class_2246.field_10539) {
				effect = class_9381.method_58256(ModParticles.BIRCH_LEAVES, world.method_67233(pos));
			} else if (this == class_2246.field_37551) {
				effect = class_9381.method_58256(ModParticles.MANGROVE_LEAVES, world.method_67233(pos));
			} else if (this == class_2246.field_10335) {
				effect = class_9381.method_58256(ModParticles.JUNGLE_LEAVES, world.method_67233(pos));
			} else if (this == class_2246.field_10098) {
				effect = class_9381.method_58256(ModParticles.ACACIA_LEAVES, world.method_67233(pos));
			} else if (this == class_2246.field_10035) {
				effect = class_9381.method_58256(ModParticles.DARK_OAK_LEAVES, world.method_67233(pos));
			}

			original.call(world, pos, random, effect);
		}
	}
}
